@@ -28,11 +28,7 @@
 #include "midgard_core_query_builder.h"
 #include "midgard_core_workspace.h"
 #include "midgard_user.h"
-
-/**
- * SECTION: MidgardConnection
- * @short_descritpion: MidgardConnection description
- */ 
+#include "sql/midgard_sql_content_manager.h"
 
 #ifdef HAVE_LIBGDA_4
 #include <sql-parser/gda-sql-parser.h>
@@ -87,6 +83,9 @@ midgard_connection_private_new (void)
 	cnc_private->workspace = NULL;
 	cnc_private->workspace_manager = NULL;
 
+	/* content_manager */
+	cnc_private->content_manager = NULL;
+
 	return cnc_private;
 }
 
@@ -167,6 +166,10 @@ static void _midgard_connection_dispose(GObject *object)
 		g_object_unref (self->priv->workspace);
 	self->priv->workspace = NULL;
 
+	if (self->priv->content_manager)
+		g_object_unref (self->priv->content_manager);
+	self->priv->content_manager = NULL;
+
 	/* Disconnect and do not invoke error callbacks */
 	if (self->priv->error_clbk_connected)
 		midgard_core_connection_disconnect_error_callback(self);
@@ -438,14 +441,6 @@ __mysql_reconnect (MidgardConnection *mgd)
 	}\
 }
 
-/**
- * Adds a named parameter to the given libgda connection string.
- 
- @param cnc libgda connection string
- @param name parameter name
- @param value parameter value
- @param def default value (used if given value is NULL)
-*/
 static void cnc_add_part(
 		GString *cnc,
 		const gchar *name, const gchar *value, const gchar *def) 
@@ -562,7 +557,7 @@ __midgard_connection_open(MidgardConnection *mgd, gboolean init_schema, GError *
 	GdaConnection *connection = gda_connection_open_from_string(
 			config->dbtype, 
 			tmpstr, auth, 
-			enable_threads ? GDA_CONNECTION_OPTIONS_THREAD_SAFE : GDA_CONNECTION_OPTIONS_NONE, 
+			enable_threads ? GDA_CONNECTION_OPTIONS_THREAD_ISOLATED : GDA_CONNECTION_OPTIONS_NONE, 
 			&err);
 	g_free(auth);	
 
@@ -1458,3 +1453,22 @@ midgard_connection_get_workspace_manager (MidgardConnection *self)
 
 	return self->priv->workspace_manager;
 }
+
+/**
+ * midgard_connection_get_content_manager:
+ * @self: #MidgardConnection instance
+ * @error: a pointer to store returned error
+ *
+ * Returns: (transfer full): #MidgardContentManager
+ * Since: 12.09
+ */ 
+MidgardContentManager*
+midgard_connection_get_content_manager (MidgardConnection *self, GError **error)
+{
+	g_return_val_if_fail (self != NULL, NULL);
+	/* TODO, handle error */
+	if (!self->priv->content_manager)
+		self->priv->content_manager = (MidgardContentManager*) g_object_new (MIDGARD_TYPE_SQL_CONTENT_MANAGER, "connection", self, NULL);
+	return (MidgardContentManager *) g_object_ref (self->priv->content_manager);
+}
+
